@@ -21,7 +21,6 @@ import (
 	"google.golang.org/grpc/credentials"
 	"google.golang.org/grpc/keepalive"
 	"google.golang.org/grpc/metadata"
-	reflectpb "google.golang.org/grpc/reflection/grpc_reflection_v1alpha"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/types/descriptorpb"
 
@@ -38,9 +37,9 @@ import (
 // the response status codes emitted use an offest of 64
 const statusCodeOffset = 64
 
-const no_version = "dev build <no version set>"
+const noVersion = "dev build <no version set>"
 
-var version = no_version
+var version = noVersion
 
 var (
 	exit = os.Exit
@@ -109,7 +108,7 @@ var (
 		separator.`))
 	allowUnknownFields = flags.Bool("allow-unknown-fields", false, prettify(`
 		When true, the request contents, if 'json' format is used, allows
-		unkown fields to be present. They will be ignored when parsing
+		unknown fields to be present. They will be ignored when parsing
 		the request.`))
 	connectTimeout = flags.Float64("connect-timeout", 0, prettify(`
 		The maximum time, in seconds, to wait for connection to be established.
@@ -445,7 +444,7 @@ func main() {
 		}
 
 		grpcurlUA := "grpcurl/" + version
-		if version == no_version {
+		if version == noVersion {
 			grpcurlUA = "grpcurl/dev-build (no version set)"
 		}
 		if *userAgent != "" {
@@ -508,7 +507,7 @@ func main() {
 		md := grpcurl.MetadataFromHeaders(append(addlHeaders, reflHeaders...))
 		refCtx := metadata.NewOutgoingContext(ctx, md)
 		cc = dial()
-		refClient = grpcreflect.NewClient(refCtx, reflectpb.NewServerReflectionClient(cc))
+		refClient = grpcreflect.NewClientAuto(refCtx, cc)
 		reflSource := grpcurl.DescriptorSourceFromServer(ctx, refClient)
 		if fileSource != nil {
 			descSource = compositeSource{reflSource, fileSource}
